@@ -1,14 +1,14 @@
-var test = require("tap").test
 var fs = require("fs")
 
 var readdir = fs.readdir
-fs.readdir = function(path, cb) {
+fs.readdir = function(path, options, cb) {
   process.nextTick(function() {
     cb(null, ["b", "z", "a"])
   })
 }
 
 var g = require("../")
+var test = require("tap").test
 
 test("readdir reorder", function (t) {
   g.readdir("whatevers", function (er, files) {
